__all__ = [
    "ID_REF_KEY",
    "ID_SEP_KEY",
    "EXPR_KEY",
    "MACRO_KEY",
]

ID_REF_KEY = "@"  # start of a reference to a ConfigItem
ID_SEP_KEY = "::"  # separator for the ID of a ConfigItem
EXPR_KEY = "$"  # start of a ConfigExpression
MACRO_KEY = "%"  # start of a macro of a config



"""
sparkwheel: A powerful YAML-based configuration system with references, expressions, and dynamic instantiation.

Uses YAML format only.
"""

from .config_item import ConfigComponent, ConfigExpression, ConfigItem, Instantiable
from .config_parser import ConfigParser
from .constants import EXPR_KEY, ID_REF_KEY, ID_SEP_KEY, MACRO_KEY
from .reference_resolver import ReferenceResolver

__version__ = "0.0.2"

__all__ = [
    "__version__",
    "ConfigParser",
    "ConfigItem",
    "ConfigComponent",
    "ConfigExpression",
    "Instantiable",
    "ReferenceResolver",
    "ID_REF_KEY",
    "ID_SEP_KEY",
    "EXPR_KEY",
    "MACRO_KEY",
]
